pub struct Url(/* private fields */);Expand description
The string representation of a URL, either absolute or relative, that has been verified as a valid URL on construction.
Implementations
Sourceimpl Url
impl Url
Sourcepub fn parse_absolute(input: &str) -> Result<Self, ParseError>
pub fn parse_absolute(input: &str) -> Result<Self, ParseError>
Sourcepub fn parse_relative(input: &str) -> Result<Self, ParseError>
pub fn parse_relative(input: &str) -> Result<Self, ParseError>
Parse a relative path as URL.
Errors
Returns an error if the string is not a relative path or can’t be converted to an url.
pub fn as_str(&self) -> &str